==> seedsui-react-5.6.22.tgz: package/lib/DatePicker/MultipleCombo/index.js <==
var _excluded = ["separator", "min", "max", "type", "value", "format", "onError", "ModalProps"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import Combo from "./../../Picker/Combo";
import MultipleModal from "./../MultipleModal";
import locale from "./../../locale";
import Utils from "./Utils"; // 日期多选

export default /*#__PURE__*/forwardRef(function (_ref, ref) {
  var separator = _ref.separator,
      min = _ref.min,
      max = _ref.max,
      type = _ref.type,
      value = _ref.value,
      format = _ref.format,
      onError = _ref.onError,
      ModalProps = _ref.ModalProps,
      props = _objectWithoutProperties(_ref, _excluded);

  // value必传
  if (!value) {
    value = [{
      type: 'date',
      id: 'start',
      name: locale('开始时间', 'start_time'),
      value: new Date()
    }, {
      type: 'date',
      id: 'end',
      name: locale('结束时间', 'end_time'),
      value: new Date()
    }];
  }

  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    var _rootRef$current, _rootRef$current2, _rootRef$current3, _rootRef$current4;

    return {
      rootDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current = rootRef.current) === null || _rootRef$current === void 0 ? void 0 : _rootRef$current.rootDOM,
      modalDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current2 = rootRef.current) === null || _rootRef$current2 === void 0 ? void 0 : _rootRef$current2.modalDOM,
      getRootDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current3 = rootRef.current) === null || _rootRef$current3 === void 0 ? void 0 : _rootRef$current3.getRootDOM,
      getModalDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current4 = rootRef.current) === null || _rootRef$current4 === void 0 ? void 0 : _rootRef$current4.getModalDOM
    };
  });
  var displayValue = Utils.getDisplayValue({
    type: type,
    format: format,
    value: value,
    separator: separator
  });
  return /*#__PURE__*/React.createElement(Combo, _extends({
    ref: rootRef,
    value: displayValue,
    ModalComponent: MultipleModal,
    ModalProps: _objectSpread({
      value: value,
      min: min,
      max: max,
      type: type,
      onError: onError
    }, ModalProps)
  }, props));
});

==> seedsui-react-5.6.42.tgz: package/lib/DatePicker/MultipleCombo/index.js <==
var _excluded = ["separator", "min", "max", "type", "value", "format", "onError", "ModalProps"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import Combo from "./../../Picker/Combo";
import MultipleModal from "./../MultipleModal";
import locale from "./../../locale";
import Utils from "./Utils"; // 日期多选

export default /*#__PURE__*/forwardRef(function (_ref, ref) {
  var separator = _ref.separator,
      min = _ref.min,
      max = _ref.max,
      type = _ref.type,
      value = _ref.value,
      format = _ref.format,
      onError = _ref.onError,
      ModalProps = _ref.ModalProps,
      props = _objectWithoutProperties(_ref, _excluded);

  // value必传
  if (!value) {
    value = [{
      type: 'date',
      id: 'start',
      name: locale('开始时间', 'start_time'),
      value: new Date()
    }, {
      type: 'date',
      id: 'end',
      name: locale('结束时间', 'end_time'),
      value: new Date()
    }];
  } // 显示文本


  var displayValue = Utils.getDisplayValue({
    type: type,
    format: format,
    value: value,
    separator: separator
  });
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    var _rootRef$current, _rootRef$current2, _rootRef$current3, _rootRef$current4;

    return {
      rootDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current = rootRef.current) === null || _rootRef$current === void 0 ? void 0 : _rootRef$current.rootDOM,
      modalDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current2 = rootRef.current) === null || _rootRef$current2 === void 0 ? void 0 : _rootRef$current2.modalDOM,
      getRootDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current3 = rootRef.current) === null || _rootRef$current3 === void 0 ? void 0 : _rootRef$current3.getRootDOM,
      getModalDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current4 = rootRef.current) === null || _rootRef$current4 === void 0 ? void 0 : _rootRef$current4.getModalDOM,
      // 显示文本
      displayValue: displayValue,
      getDisplayValue: function getDisplayValue(newValue) {
        return Utils.getDisplayValue({
          type: type,
          format: format,
          value: newValue || value,
          separator: separator
        });
      }
    };
  });
  return /*#__PURE__*/React.createElement(Combo, _extends({
    ref: rootRef,
    value: displayValue,
    ModalComponent: MultipleModal,
    ModalProps: _objectSpread({
      value: value,
      min: min,
      max: max,
      type: type,
      onError: onError
    }, ModalProps)
  }, props));
});
